<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko_KR">
<context>
    <name>AuthenticationWidget</name>
    <message>
        <location filename="../src/GUI/authenticationwidget.cpp" line="15"/>
        <source>Username:</source>
        <translation>사용자 이름:</translation>
    </message>
    <message>
        <location filename="../src/GUI/authenticationwidget.cpp" line="16"/>
        <source>Password:</source>
        <translation>암호:</translation>
    </message>
</context>
<context>
    <name>CadenceGraph</name>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="11"/>
        <source>rpm</source>
        <translation>rpm</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="12"/>
        <location filename="../src/GUI/cadencegraph.h" line="16"/>
        <source>Cadence</source>
        <translation>케이던스</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>평균</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="30"/>
        <source>Max</source>
        <translation>최대</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="33"/>
        <source>Average</source>
        <translation>평균</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>최대</translation>
    </message>
</context>
<context>
    <name>CadenceGraphItem</name>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="18"/>
        <source>Maximum</source>
        <translation>최대</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="19"/>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="21"/>
        <source>rpm</source>
        <translation>rpm</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="20"/>
        <source>Average</source>
        <translation>평균</translation>
    </message>
</context>
<context>
    <name>Data</name>
    <message>
        <location filename="../src/data/data.cpp" line="234"/>
        <source>Supported files</source>
        <translation>지원되는 파일</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="235"/>
        <source>CSV files</source>
        <translation>CSV 파일</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="236"/>
        <source>CUP files</source>
        <translation>CUP 파일</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="237"/>
        <source>FIT files</source>
        <translation>FIT 파일</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="238"/>
        <source>GeoJSON files</source>
        <translation>GeoJSON 파일</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="239"/>
        <source>GPI files</source>
        <translation>GPI 파일</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="240"/>
        <source>GPX files</source>
        <translation>GPX 파일</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="241"/>
        <source>IGC files</source>
        <translation>IGC 파일</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="242"/>
        <source>ITN files</source>
        <translation>ITN 파일</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="243"/>
        <source>JPEG images</source>
        <translation>JPEG 이미지</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="244"/>
        <source>KML files</source>
        <translation>KML 파일</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="245"/>
        <source>LOC files</source>
        <translation>LOC 파일</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="246"/>
        <source>NMEA files</source>
        <translation>NMEA 파일</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="247"/>
        <source>ONmove files</source>
        <translation>ONmove 파일</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="248"/>
        <source>OV2 files</source>
        <translation>OV2 파일</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="249"/>
        <source>OziExplorer files</source>
        <translation>OziExplorer 파일</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="250"/>
        <source>SLF files</source>
        <translation>SLF 파일</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="251"/>
        <source>SML files</source>
        <translation>SML 파일</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="252"/>
        <source>TCX files</source>
        <translation>TCX 파일</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="253"/>
        <source>70mai GPS log files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="254"/>
        <source>VKX files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="255"/>
        <source>VTK files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="256"/>
        <source>TwoNav files</source>
        <translation>TwoNav 파일</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="257"/>
        <source>GPSDump files</source>
        <translation>GPSDump 파일</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="258"/>
        <source>All files</source>
        <translation>모든 파일</translation>
    </message>
</context>
<context>
    <name>DirSelectWidget</name>
    <message>
        <location filename="../src/GUI/dirselectwidget.cpp" line="18"/>
        <source>System default</source>
        <translation>시스템 기본값</translation>
    </message>
    <message>
        <location filename="../src/GUI/dirselectwidget.cpp" line="40"/>
        <source>Select directory</source>
        <translation>디렉터리 선택</translation>
    </message>
</context>
<context>
    <name>ElevationGraph</name>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="39"/>
        <location filename="../src/GUI/elevationgraph.h" line="16"/>
        <source>Elevation</source>
        <translation>고도</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="59"/>
        <source>Up</source>
        <extracomment>Use an Unicode arrow (U+2197) when there is no abbreviation or extremly short term for &quot;Up&quot; in your language</extracomment>
        <translation>위</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="63"/>
        <source>Down</source>
        <extracomment>Use an Unicode arrow (U+2198) when there is no abbreviation or extremly short term for &quot;Down&quot; in your language</extracomment>
        <translation>아래</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="66"/>
        <source>Max</source>
        <extracomment>Use an abbreviation or a extremly short term</extracomment>
        <translation>최대</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="69"/>
        <source>Min</source>
        <extracomment>Use an abbreviation or a extremly short term</extracomment>
        <translation>최소</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="72"/>
        <source>Ascent</source>
        <translation>상승</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="74"/>
        <source>Descent</source>
        <translation>하강</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="76"/>
        <source>Maximum</source>
        <translation>최대</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="78"/>
        <source>Minimum</source>
        <translation>최소</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="181"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="184"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
</context>
<context>
    <name>ElevationGraphItem</name>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="35"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="35"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="38"/>
        <source>Ascent</source>
        <translation>상승</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="40"/>
        <source>Descent</source>
        <translation>하강</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="42"/>
        <source>Maximum</source>
        <translation>최대</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="44"/>
        <source>Minimum</source>
        <translation>최소</translation>
    </message>
</context>
<context>
    <name>FileSelectWidget</name>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="46"/>
        <location filename="../src/GUI/fileselectwidget.cpp" line="51"/>
        <source>Select file</source>
        <translation>파일 선택</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="61"/>
        <source>No output file selected.</source>
        <translation>출력 파일을 선택하지 않았습니다.</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="71"/>
        <source>%1 is a directory.</source>
        <translation>%1은 디렉터리입니다.</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="75"/>
        <source>%1 is not writable.</source>
        <translation>%1을 쓸 수 없습니다.</translation>
    </message>
</context>
<context>
    <name>Format</name>
    <message>
        <location filename="../src/GUI/format.cpp" line="54"/>
        <location filename="../src/GUI/format.cpp" line="64"/>
        <location filename="../src/GUI/format.cpp" line="93"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="57"/>
        <location filename="../src/GUI/format.cpp" line="60"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="67"/>
        <location filename="../src/GUI/format.cpp" line="70"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="74"/>
        <location filename="../src/GUI/format.cpp" line="90"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="77"/>
        <location filename="../src/GUI/format.cpp" line="80"/>
        <source>km</source>
        <translation>km</translation>
    </message>
</context>
<context>
    <name>GUI</name>
    <message>
        <location filename="../src/GUI/gui.cpp" line="200"/>
        <source>Quit</source>
        <translation>종료</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="208"/>
        <location filename="../src/GUI/gui.cpp" line="975"/>
        <location filename="../src/GUI/gui.cpp" line="993"/>
        <source>Paths</source>
        <translation>경로</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="212"/>
        <location filename="../src/GUI/gui.cpp" line="935"/>
        <location filename="../src/GUI/gui.cpp" line="936"/>
        <source>Keyboard controls</source>
        <translation>키보드 제어</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="216"/>
        <location filename="../src/GUI/gui.cpp" line="902"/>
        <source>About GPXSee</source>
        <translation>GPXSee 정보</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="222"/>
        <source>Open...</source>
        <translation>열기...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="229"/>
        <source>Open directory...</source>
        <translation>디렉터리 열기...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="234"/>
        <source>Print...</source>
        <translation>인쇄...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="240"/>
        <source>Export to PDF...</source>
        <translation>PDF로 내보내기...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="247"/>
        <source>Export to PNG...</source>
        <translation>PNG로 내보내기...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="254"/>
        <source>Close</source>
        <translation>닫기</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="261"/>
        <source>Reload</source>
        <translation>다시 불러오기</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="267"/>
        <source>Statistics...</source>
        <translation>통계...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="277"/>
        <source>Clear list</source>
        <translation>목록 지우기</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="289"/>
        <source>Load POI file...</source>
        <translation>POI 파일 불러오기...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="293"/>
        <source>Select all files</source>
        <translation>모든 파일 선택</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="298"/>
        <source>Unselect all files</source>
        <translation>모든 파일 선택 취소</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="303"/>
        <source>Overlap POIs</source>
        <translation>중첩 POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="308"/>
        <source>Show POI icons</source>
        <translation>POI 아이콘 표시</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="313"/>
        <source>Show POI labels</source>
        <translation>POI 레이블 표시</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="319"/>
        <source>Show POIs</source>
        <translation>POI 표시</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="331"/>
        <source>Show map</source>
        <translation>지도 표시</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="340"/>
        <source>Load map...</source>
        <translation>지도 불러오기...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="345"/>
        <source>Load map directory...</source>
        <translation>지도 디렉터리 불러오기...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="348"/>
        <source>Clear tile cache</source>
        <translation>타일 캐시 지우기</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="353"/>
        <location filename="../src/GUI/gui.cpp" line="358"/>
        <location filename="../src/GUI/gui.cpp" line="954"/>
        <source>Next map</source>
        <translation>다음 지도</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="363"/>
        <source>Show cursor coordinates</source>
        <translation>커서 좌표 표시</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="371"/>
        <source>All</source>
        <translation>모두</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="375"/>
        <source>Raster only</source>
        <translation>래스터만</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="379"/>
        <source>Vector only</source>
        <translation>벡터만</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="386"/>
        <source>Show position</source>
        <translation>위치 표시</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="392"/>
        <source>Follow position</source>
        <translation>추종 위치</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="397"/>
        <source>Show coordinates</source>
        <translation>좌표 표시</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="403"/>
        <source>Show motion info</source>
        <translation>모션 정보 표시</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="410"/>
        <source>Show tracks</source>
        <translation>트랙 표시</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="415"/>
        <source>Show routes</source>
        <translation>경로 표시</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="420"/>
        <source>Show waypoints</source>
        <translation>경유지 표시</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="426"/>
        <source>Show areas</source>
        <translation>영역 표시</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="431"/>
        <source>Waypoint icons</source>
        <translation>경유지 아이콘</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="436"/>
        <source>Waypoint labels</source>
        <translation>경유지 레이블</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="441"/>
        <source>Route waypoints</source>
        <translation>경유지 경로</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="446"/>
        <source>km/mi markers</source>
        <translation>km/mi 마커</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="454"/>
        <source>Do not show</source>
        <translation>표시 안 함</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="458"/>
        <source>Marker only</source>
        <translation>마커만</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="462"/>
        <source>Date/time</source>
        <translation>날짜/시간</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="466"/>
        <source>Coordinates</source>
        <translation>좌표</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="470"/>
        <source>Use styles</source>
        <translation>스타일 사용</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="477"/>
        <source>Download data DEM</source>
        <translation>데이터 DEM 다운로드</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="483"/>
        <source>Download map DEM</source>
        <translation>지도 DEM 다운로드</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="488"/>
        <source>Show local DEM tiles</source>
        <translation>로컬 DEM 타일 표시</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="491"/>
        <source>Show hillshading</source>
        <translation>언덕 음영 표시</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="499"/>
        <source>Show graphs</source>
        <translation>그래프 표시</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="507"/>
        <location filename="../src/GUI/gui.cpp" line="1445"/>
        <location filename="../src/GUI/gui.cpp" line="1505"/>
        <source>Distance</source>
        <translation>거리</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="514"/>
        <location filename="../src/GUI/gui.cpp" line="764"/>
        <location filename="../src/GUI/gui.cpp" line="1447"/>
        <location filename="../src/GUI/gui.cpp" line="1507"/>
        <source>Time</source>
        <translation>시간</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="520"/>
        <source>Show grid</source>
        <translation>격자 표시</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="525"/>
        <source>Show slider info</source>
        <translation>슬라이더 정보 표시</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="531"/>
        <source>Show tabs</source>
        <translation>탭 표시</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="540"/>
        <source>Show toolbars</source>
        <translation>도구 모음 표시</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="547"/>
        <source>Total time</source>
        <translation>총 시간</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="552"/>
        <location filename="../src/GUI/gui.cpp" line="1448"/>
        <location filename="../src/GUI/gui.cpp" line="1509"/>
        <source>Moving time</source>
        <translation>이동시간</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="559"/>
        <source>Metric</source>
        <translation>미터법</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="564"/>
        <source>Imperial</source>
        <translation>야드·파운드법</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="570"/>
        <source>Nautical</source>
        <translation>항해</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="578"/>
        <source>Decimal degrees (DD)</source>
        <translation>십진법 (DD)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="584"/>
        <source>Degrees and decimal minutes (DMM)</source>
        <translation>도 및 소수 분 (DMM)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="591"/>
        <source>Degrees, minutes, seconds (DMS)</source>
        <translation>도, 분, 초 (DMS)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="598"/>
        <source>Fullscreen mode</source>
        <translation>전체 화면 모드</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="605"/>
        <source>Options...</source>
        <translation>옵션...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="612"/>
        <source>Next</source>
        <translation>다음</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="617"/>
        <source>Previous</source>
        <translation>이전</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="622"/>
        <source>Last</source>
        <translation>마지막</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="627"/>
        <source>First</source>
        <translation>처음</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="662"/>
        <source>&amp;File</source>
        <translation>파일(&amp;F)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="665"/>
        <source>Open recent</source>
        <translation>최근 열기</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="690"/>
        <source>&amp;Map</source>
        <translation>지도(&amp;M)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="696"/>
        <source>Layers</source>
        <translation>레이어</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="705"/>
        <source>&amp;Graph</source>
        <translation>그래프(&amp;G)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="717"/>
        <source>&amp;Data</source>
        <translation>데이터(&amp;D)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="722"/>
        <source>Position info</source>
        <translation>위치 정보</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="736"/>
        <source>&amp;POI</source>
        <translation>POI(&amp;P)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="748"/>
        <source>DEM</source>
        <translation>DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="756"/>
        <source>Position</source>
        <translation>위치</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="763"/>
        <source>&amp;Settings</source>
        <translation>설정(&amp;S)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="768"/>
        <source>Units</source>
        <translation>단위</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="773"/>
        <source>Coordinates format</source>
        <translation>좌표 형식</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="786"/>
        <source>&amp;Help</source>
        <translation>도움말(&amp;H)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="813"/>
        <source>File</source>
        <translation>파일</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="823"/>
        <source>Show</source>
        <translation>표시</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="831"/>
        <source>Navigation</source>
        <translation>네비게이션</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="904"/>
        <location filename="../src/GUI/gui.cpp" line="912"/>
        <source>Version %1</source>
        <translation>버전 %1</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="907"/>
        <location filename="../src/GUI/gui.cpp" line="916"/>
        <source>GPXSee is distributed under the terms of the GNU General Public License version 3. For more info about GPXSee visit the project homepage at %1.</source>
        <translation>GPXSee는 GNU General Public License 버전 3의 조건에 따라 배포됩니다. GPX에 대한 자세한 내용은 %1의 프로젝트 홈페이지를 참조하십시오.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="939"/>
        <source>Next file</source>
        <translation>다음 파일</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="940"/>
        <source>Previous file</source>
        <translation>이전 파일</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="942"/>
        <source>First file</source>
        <translation>첫 번째 파일</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="944"/>
        <source>Last file</source>
        <translation>마지막 파일</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="945"/>
        <source>Append file</source>
        <translation>파일 추가</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="946"/>
        <source>Next/Previous</source>
        <translation>다음/이전</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="948"/>
        <source>Toggle graph type</source>
        <translation>그래프 유형 전환</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="950"/>
        <source>Toggle time type</source>
        <translation>시간 유형 전환</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="952"/>
        <source>Toggle position info</source>
        <translation>위치 정보 전환</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="956"/>
        <source>Previous map</source>
        <translation>이전 지도</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="957"/>
        <source>Zoom in</source>
        <translation>확대</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="959"/>
        <source>Zoom out</source>
        <translation>축소</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="961"/>
        <source>Digital zoom</source>
        <translation>디지털 줌</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="962"/>
        <source>Zoom</source>
        <translation>확대/축소</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="963"/>
        <source>Copy coordinates</source>
        <translation>좌표 복사</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="964"/>
        <source>Left Click</source>
        <translation>왼쪽 클릭</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="978"/>
        <location filename="../src/GUI/gui.cpp" line="996"/>
        <source>Map directory:</source>
        <translation>지도 디렉터리:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="980"/>
        <location filename="../src/GUI/gui.cpp" line="998"/>
        <source>POI directory:</source>
        <translation>POI 디렉터리:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="982"/>
        <location filename="../src/GUI/gui.cpp" line="1000"/>
        <source>CRS directory:</source>
        <translation>CRS 디렉토리:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="984"/>
        <location filename="../src/GUI/gui.cpp" line="1002"/>
        <source>DEM directory:</source>
        <translation>DEM 디렉터리:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="986"/>
        <location filename="../src/GUI/gui.cpp" line="1004"/>
        <source>Styles directory:</source>
        <translation>스타일 디렉터리:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="988"/>
        <location filename="../src/GUI/gui.cpp" line="1006"/>
        <source>Symbols directory:</source>
        <translation>기호 디렉터리:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="990"/>
        <location filename="../src/GUI/gui.cpp" line="1008"/>
        <source>Tile cache directory:</source>
        <translation>타일 캐시 디렉터리:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1019"/>
        <location filename="../src/GUI/gui.cpp" line="1022"/>
        <source>Open file</source>
        <translation>파일 열기</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1054"/>
        <source>Open directory</source>
        <translation>디렉터리 열기</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1126"/>
        <source>Error loading geo URI:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1164"/>
        <source>Error loading data file:</source>
        <translation>데이터 파일 불어오는 중 오류 발생:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1167"/>
        <location filename="../src/GUI/gui.cpp" line="1283"/>
        <source>Line: %1</source>
        <translation>줄: %1</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1132"/>
        <location filename="../src/GUI/gui.cpp" line="1172"/>
        <location filename="../src/GUI/gui.cpp" line="1865"/>
        <location filename="../src/GUI/gui.cpp" line="1971"/>
        <source>Don&apos;t show again</source>
        <translation>다시 표시 안 함</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1250"/>
        <location filename="../src/GUI/gui.cpp" line="1253"/>
        <source>Open POI file</source>
        <translation>POI 파일 열기</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1280"/>
        <source>Error loading POI file:</source>
        <translation>POI 파일 불어오는 중 오류 발생:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1427"/>
        <location filename="../src/GUI/gui.cpp" line="1485"/>
        <source>Tracks</source>
        <translation>트랙</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1429"/>
        <location filename="../src/GUI/gui.cpp" line="1487"/>
        <source>Routes</source>
        <translation>경로</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1431"/>
        <location filename="../src/GUI/gui.cpp" line="1489"/>
        <source>Waypoints</source>
        <translation>경유지</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1433"/>
        <location filename="../src/GUI/gui.cpp" line="1491"/>
        <source>Areas</source>
        <translation>영역</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1437"/>
        <location filename="../src/GUI/gui.cpp" line="1439"/>
        <location filename="../src/GUI/gui.cpp" line="1496"/>
        <location filename="../src/GUI/gui.cpp" line="1498"/>
        <source>Date</source>
        <translation>날짜</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1460"/>
        <location filename="../src/GUI/gui.cpp" line="1463"/>
        <location filename="../src/GUI/gui.cpp" line="1464"/>
        <source>Statistics</source>
        <translation>통계</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1481"/>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1804"/>
        <location filename="../src/GUI/gui.cpp" line="1807"/>
        <source>Open map file</source>
        <translation>지도 파일 열기</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1859"/>
        <location filename="../src/GUI/gui.cpp" line="1922"/>
        <location filename="../src/GUI/gui.cpp" line="1941"/>
        <location filename="../src/GUI/gui.cpp" line="1965"/>
        <source>Error loading map:</source>
        <translation>지도 불러오는 중 오류 발생:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2005"/>
        <source>Select map directory</source>
        <translation>지도 디렉터리 선택</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2034"/>
        <source>Clear &quot;%1&quot; tile cache?</source>
        <translation>%1 타일 캐시를 지우시겠습니까?</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2054"/>
        <source>DEM tiles download limit exceeded. If you really need data for such a huge area, download the files manually.</source>
        <translation>DEM 타일 다운로드 제한을 초과했습니다. 이렇게 넓은 지역에 대한 데이터가 정말 필요하다면 수동으로 파일을 다운로드하세요.</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/GUI/gui.cpp" line="2057"/>
        <source>Download %n DEM tiles?</source>
        <translation>
            <numerusform>%n개의 DEM 타일을 다운로드하시겠습니까?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2070"/>
        <source>Could not download all required DEM files.</source>
        <translation>필요한 모든 DEM 파일을 다운로드할 수 없습니다.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2087"/>
        <source>No local DEM tiles found.</source>
        <translation>로컬 DEM 타일을 찾을 수 없습니다.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2101"/>
        <source>No files loaded</source>
        <translation>불러온 파일이 없습니다</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/GUI/gui.cpp" line="2105"/>
        <source>%n files</source>
        <translation>
            <numerusform>%n개 파일</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GearRatioGraph</name>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="12"/>
        <location filename="../src/GUI/gearratiograph.h" line="17"/>
        <source>Gear ratio</source>
        <translation>기어 비율</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="28"/>
        <source>Top</source>
        <translation>상단</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="30"/>
        <source>Min</source>
        <translation>최소</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="32"/>
        <source>Max</source>
        <translation>최대</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="35"/>
        <source>Most used</source>
        <translation>가장 많이 사용됨</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="37"/>
        <source>Minimum</source>
        <translation>최소</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="39"/>
        <source>Maximum</source>
        <translation>최대</translation>
    </message>
</context>
<context>
    <name>GearRatioGraphItem</name>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="37"/>
        <source>Minimum</source>
        <translation>최소</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="38"/>
        <source>Maximum</source>
        <translation>최대</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="39"/>
        <source>Most used</source>
        <translation>가장 많이 사용됨</translation>
    </message>
</context>
<context>
    <name>GraphView</name>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="67"/>
        <source>Data not available</source>
        <translation>데이터를 사용할 수 없음</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="86"/>
        <location filename="../src/GUI/graphview.cpp" line="191"/>
        <source>Distance</source>
        <translation>거리</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="123"/>
        <location filename="../src/GUI/graphview.cpp" line="131"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="126"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="134"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="139"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="142"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="148"/>
        <source>s</source>
        <translation>초</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="151"/>
        <source>min</source>
        <translation>분</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="154"/>
        <source>h</source>
        <translation>시</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="193"/>
        <source>Time</source>
        <translation>시간</translation>
    </message>
</context>
<context>
    <name>HeartRateGraph</name>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="11"/>
        <source>bpm</source>
        <translation>bpm</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="12"/>
        <location filename="../src/GUI/heartrategraph.h" line="16"/>
        <source>Heart rate</source>
        <translation>심박수</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>평균</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="30"/>
        <source>Max</source>
        <translation>최대</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="33"/>
        <source>Average</source>
        <translation>평균</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>최대</translation>
    </message>
</context>
<context>
    <name>HeartRateGraphItem</name>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="19"/>
        <source>Maximum</source>
        <translation>최대</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="20"/>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="22"/>
        <source>bpm</source>
        <translation>bpm</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="21"/>
        <source>Average</source>
        <translation>평균</translation>
    </message>
</context>
<context>
    <name>MapItem</name>
    <message>
        <location filename="../src/GUI/mapitem.cpp" line="80"/>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <location filename="../src/GUI/mapitem.cpp" line="82"/>
        <source>File</source>
        <translation>파일</translation>
    </message>
</context>
<context>
    <name>MapList</name>
    <message>
        <location filename="../src/map/maplist.cpp" line="158"/>
        <source>Supported files</source>
        <translation>지원되는 파일</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="160"/>
        <source>Electronic Navigational Charts</source>
        <translation>전자 항법 차트</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="162"/>
        <source>AlpineQuest maps</source>
        <translation>알파인 퀘스트 지도</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="163"/>
        <source>GEMF maps</source>
        <translation>GEMF 지도</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="164"/>
        <source>Garmin IMG maps</source>
        <translation>Garmin IMG 지도</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="166"/>
        <source>Garmin JNX maps</source>
        <translation>Garmin JNX 지도</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="167"/>
        <source>BSB nautical charts</source>
        <translation>BSB 해도</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="168"/>
        <source>KMZ maps</source>
        <translation>KMZ 지도</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="169"/>
        <source>Mapsforge maps</source>
        <translation>Mapsforge 지도</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="170"/>
        <source>OziExplorer maps</source>
        <translation>OziExplorer 지도</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="171"/>
        <source>MBTiles maps</source>
        <translation>MBTiles 지도</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="172"/>
        <source>Orux maps</source>
        <translation>Orux 지도</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="173"/>
        <source>QuickChart maps</source>
        <translation>QuickChart 지도</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="174"/>
        <source>TwoNav maps</source>
        <translation>TwoNav 지도</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="175"/>
        <source>Osmdroid SQLite maps</source>
        <translation>Osmdroid SQLite 지도</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="176"/>
        <source>Locus/OsmAnd/RMaps SQLite maps</source>
        <translation>Locus/OsmAnd/RMaps SQLite 지도</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="178"/>
        <source>TrekBuddy maps/atlases</source>
        <translation>TrekBuddy 지도/도면</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="180"/>
        <source>GeoTIFF images</source>
        <translation>GeoTIFF 이미지</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="181"/>
        <source>World-file georeferenced images</source>
        <translation>월드 파일 지리 참조 이미지</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="183"/>
        <source>Online map sources</source>
        <translation>온라인 지도 소스</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="184"/>
        <source>All files</source>
        <translation>모든 파일</translation>
    </message>
</context>
<context>
    <name>MotionInfoItem</name>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="87"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="90"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="93"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="100"/>
        <source>ft/min</source>
        <translation>ft/min</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="103"/>
        <source>m/min</source>
        <translation>m/min</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="78"/>
        <source>Select the proper coordinate reference system (CRS) of maps without a CRS definition (JNX, KMZ and World file maps).</source>
        <translation>CRS 정의가 없는 지도 (JNX, KMZ 및 World 파일 맵)의 적절한 좌표 참조 시스템(CRS)을 선택합니다.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="81"/>
        <source>Select the desired projection of vector maps (IMG, Mapsforge and ENC maps). The projection must be valid for the whole map area.</source>
        <translation>원하는 벡터 지도 투영(IMG, Mapsforge 및 ENC 지도)을 선택합니다. 투영은 전체 지도 영역에 대해 유효해야 합니다.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="86"/>
        <source>Standard</source>
        <translation>표준</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="91"/>
        <source>Non-HiDPI maps are loaded as HiDPI maps. The map is sharp but map objects are small/hard to read.</source>
        <translation>비 HiDPI 지도는 HiDPI 지도로 불러옵니다. 지도는 날카롭지만 지도 객체가 작거나 읽기 어렵습니다.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="93"/>
        <source>Non-HiDPI maps are loaded such as they are. Map objects have the expected size but the map is blurry.</source>
        <translation>비 HiDPI 지도는 그대로 불러옵니다. 지도 개체의 크기가 예상되지만 지도가 흐립니다.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="103"/>
        <source>Input</source>
        <translation>입력</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="105"/>
        <source>Output</source>
        <translation>출력</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="112"/>
        <source>Input:</source>
        <translation>입력:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="115"/>
        <source>Output:</source>
        <translation>출력:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="136"/>
        <source>Projection</source>
        <translation>프로젝션</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="137"/>
        <source>HiDPI display mode</source>
        <translation>HiDPI 디스플레이 모드</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="147"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="154"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="160"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="228"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="235"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="273"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="639"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="171"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="275"/>
        <source>Use anti-aliasing</source>
        <translation>안티앨리어싱 사용</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="177"/>
        <source>Track width:</source>
        <translation>트랙 너비:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="178"/>
        <source>Track style:</source>
        <translation>트랙 스타일:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="180"/>
        <source>Route width:</source>
        <translation>경로 너비:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="181"/>
        <source>Route style:</source>
        <translation>경로 스타일:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="183"/>
        <source>Area border width:</source>
        <translation>영역 경계 너비:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="184"/>
        <source>Area border style:</source>
        <translation>영역 경계 스타일:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="185"/>
        <source>Area fill opacity:</source>
        <translation>영역 채우기 불투명도:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="187"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="210"/>
        <source>Base color:</source>
        <translation>기본 색상:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="188"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="211"/>
        <source>Palette shift:</source>
        <translation>팔레트 이동:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="194"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="199"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="204"/>
        <source>Width:</source>
        <translation>너비:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="195"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="200"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="205"/>
        <source>Style:</source>
        <translation>스타일:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="196"/>
        <source>Tracks</source>
        <translation>트랙</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="201"/>
        <source>Routes</source>
        <translation>경로</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="207"/>
        <source>Areas</source>
        <translation>영역</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="243"/>
        <source>Waypoint color:</source>
        <translation>경유지 색상:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="244"/>
        <source>Waypoint size:</source>
        <translation>경유지 크기:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="246"/>
        <source>POI color:</source>
        <translation>POI 색상:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="247"/>
        <source>POI size:</source>
        <translation>POI 크기:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="251"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="256"/>
        <source>Color:</source>
        <translation>색상:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="252"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="257"/>
        <source>Size:</source>
        <translation>크기:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="253"/>
        <source>Waypoints</source>
        <translation>경유지</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="258"/>
        <source>POIs</source>
        <translation>POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="281"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="287"/>
        <source>Line width:</source>
        <translation>선 너비:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="282"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="288"/>
        <source>Slider color:</source>
        <translation>슬라이더 색상:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="309"/>
        <source>Info background</source>
        <translation>정보 배경</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="313"/>
        <source>Background color:</source>
        <translation>배경 색상:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="315"/>
        <source>Crosshair color:</source>
        <translation>십자선 색상:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="316"/>
        <source>Info color:</source>
        <translation>정보 색상:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="326"/>
        <source>Paths</source>
        <translation>경로</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="327"/>
        <source>Points</source>
        <translation>지점</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="328"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="764"/>
        <source>Graphs</source>
        <translation>그래프</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="329"/>
        <source>Map</source>
        <translation>지도</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="336"/>
        <source>Moving average window size</source>
        <translation>이동 평균 창 크기</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="354"/>
        <source>Eliminate GPS outliers</source>
        <translation>GPS 특이치 제거</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="360"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="378"/>
        <source>Smoothing</source>
        <translation>평활</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="361"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="371"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="495"/>
        <source>Elevation:</source>
        <translation>고도:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="362"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="372"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="494"/>
        <source>Speed:</source>
        <translation>속도:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="363"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="373"/>
        <source>Heart rate:</source>
        <translation>심박수:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="364"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="374"/>
        <source>Cadence:</source>
        <translation>케이던스:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="365"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="375"/>
        <source>Power:</source>
        <translation>파워:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="388"/>
        <source>Detect pauses</source>
        <translation>일시 중지 감지</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="391"/>
        <source>Automatic</source>
        <translation>자동</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="392"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="446"/>
        <source>Custom</source>
        <translation>사용자 지정</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="405"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="408"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="411"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="415"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="791"/>
        <source>s</source>
        <translation>초</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="426"/>
        <source>Computed from distance/time</source>
        <translation>거리/시간으로 계산됨</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="427"/>
        <source>Recorded by device</source>
        <translation>장치별로 기록</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="432"/>
        <source>Show secondary speed</source>
        <translation>보조 속도 표시</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="435"/>
        <source>GPS data</source>
        <translation>GPS 데이터</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="436"/>
        <source>DEM data</source>
        <translation>DEM 데이터</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="441"/>
        <source>Show secondary elevation</source>
        <translation>보조 고도 표시</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="444"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="445"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="842"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="893"/>
        <source>System</source>
        <translation>시스템</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="465"/>
        <source>Use segments</source>
        <translation>세그먼트 사용</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="496"/>
        <source>Time zone:</source>
        <translation>시간대:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="510"/>
        <source>Speed</source>
        <translation>속도</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="515"/>
        <source>Elevation</source>
        <translation>고도</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="521"/>
        <source>Time zone</source>
        <translation>시간대</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="537"/>
        <source>Detection:</source>
        <translation>감지:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="538"/>
        <source>Minimal speed:</source>
        <translation>최소 속도:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="539"/>
        <source>Minimal duration:</source>
        <translation>최소 지속 시간:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="550"/>
        <source>Sources</source>
        <translation>소스</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="551"/>
        <source>Filtering</source>
        <translation>필터링</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="552"/>
        <source>Pause detection</source>
        <translation>일시 중지 감지</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="564"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="567"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="570"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="574"/>
        <source>Radius:</source>
        <translation>반지름:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="580"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="884"/>
        <source>POI</source>
        <translation>POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="597"/>
        <source>Use HTTP authentication</source>
        <translation>HTTP 인증 사용</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="603"/>
        <source>Use $lat and $lon for NYY/SYY and EXXX/WXXX in the URL.</source>
        <translation>URL에서 NYY/SYY 및 EXXX/WXXX의 경우 $lat 및 $lon을 사용합니다.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="608"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="621"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="206"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="314"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="655"/>
        <source>Opacity:</source>
        <translation>불투명:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="657"/>
        <source>Blur radius:</source>
        <translation>흐림 반경:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="659"/>
        <source>Azimuth:</source>
        <translation>방위:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="660"/>
        <source>Altitude:</source>
        <translation>고도:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="661"/>
        <source>Z Factor:</source>
        <translation>Z 요인:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="666"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="696"/>
        <source>Source</source>
        <translation>소스</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="667"/>
        <source>Hillshading</source>
        <translation>언덕 음영</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="685"/>
        <source>Plugin:</source>
        <translation>플러그인:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="703"/>
        <source>WYSIWYG</source>
        <translation>WYSIWYG</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="85"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="704"/>
        <source>High-Resolution</source>
        <translation>고해상도</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="656"/>
        <source>Lightening:</source>
        <translation>라이트닝:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="709"/>
        <source>The printed area is approximately the display area. The map zoom level does not change.</source>
        <translation>인쇄된 영역은 대략 표시 영역입니다. 지도 확대/축소 수준은 변경되지 않습니다.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="711"/>
        <source>The zoom level will be changed so that the whole content (tracks/waypoints) fits to the printed area and the map resolution is as close as possible to the print resolution.</source>
        <translation>전체 콘텐츠 (트랙/경유지)가 인쇄 영역에 맞고 지도 해상도가 인쇄 해상도에 최대한 근접하도록 확대/축소 수준이 변경됩니다.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="727"/>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="729"/>
        <source>Date</source>
        <translation>날짜</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="731"/>
        <source>Distance</source>
        <translation>거리</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="733"/>
        <source>Time</source>
        <translation>시간</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="735"/>
        <source>Moving time</source>
        <translation>이동 시간</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="737"/>
        <source>Item count (&gt;1)</source>
        <translation>항목수 (&gt;1)</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="752"/>
        <source>Separate graph page</source>
        <translation>별도 그래프 페이지</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="762"/>
        <source>Print mode</source>
        <translation>인쇄 모드</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="763"/>
        <source>Header</source>
        <translation>머리말</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="771"/>
        <source>Use OpenGL</source>
        <translation>OpenGL 사용</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="773"/>
        <source>Enable HTTP/2</source>
        <translation>HTTP/2 사용</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="779"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="785"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="797"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="805"/>
        <source>Image cache size:</source>
        <translation>이미지 캐시 크기:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="799"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="807"/>
        <source>Connection timeout:</source>
        <translation>연결 시간 초과:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="798"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="806"/>
        <source>DEM cache size:</source>
        <translation>DEM 캐시 크기:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="826"/>
        <source>Select the initial paths of the file open dialogues. Leave the field empty for the system default.</source>
        <translation>파일 열기 대화 상자의 초기 경로를 선택합니다. 시스템 기본값의 경우 필드를 비워 둡니다.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="830"/>
        <source>Data:</source>
        <translation>날짜:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="831"/>
        <source>Maps:</source>
        <translation>지도:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="832"/>
        <source>POI:</source>
        <translation>POI:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="843"/>
        <source>Initial paths</source>
        <translation>초기 경로</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="879"/>
        <source>Appearance</source>
        <translation>모양새</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="881"/>
        <source>Maps</source>
        <translation>지도</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="883"/>
        <source>Data</source>
        <translation>데이터</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="886"/>
        <source>DEM</source>
        <translation>DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="889"/>
        <source>Position</source>
        <translation>위치</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="891"/>
        <source>Print &amp; Export</source>
        <translation>인쇄 및 내보내기</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="926"/>
        <source>Options</source>
        <translation>옵션</translation>
    </message>
</context>
<context>
    <name>PDFExportDialog</name>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="28"/>
        <source>PDF files</source>
        <translation>PDF 파일</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="28"/>
        <source>All files</source>
        <translation>모든 파일</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="56"/>
        <source>Portrait</source>
        <translation>세로</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="57"/>
        <source>Landscape</source>
        <translation>가로</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="67"/>
        <source>cm</source>
        <translation>cm</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="67"/>
        <source>in</source>
        <translation>인치</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="73"/>
        <source>Page Setup</source>
        <translation>페이지 설정</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="76"/>
        <source>Page size:</source>
        <translation>페이지 크기:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="77"/>
        <source>Resolution:</source>
        <translation>해상도:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="78"/>
        <source>Orientation:</source>
        <translation>방향:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="79"/>
        <source>Margins:</source>
        <translation>여백:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="85"/>
        <source>File:</source>
        <translation>파일:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="92"/>
        <source>Output file</source>
        <translation>출력 파일</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="99"/>
        <source>Export</source>
        <translation>내보내기</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="119"/>
        <source>Export to PDF</source>
        <translation>PDF로 내보내기</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="127"/>
        <source>Error</source>
        <translation>오류</translation>
    </message>
</context>
<context>
    <name>PNGExportDialog</name>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="25"/>
        <source>PNG files</source>
        <translation>PNG 파일</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="25"/>
        <source>All files</source>
        <translation>모든 파일</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="34"/>
        <location filename="../src/GUI/pngexportdialog.cpp" line="39"/>
        <location filename="../src/GUI/pngexportdialog.cpp" line="43"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="45"/>
        <source>Use anti-aliasing</source>
        <translation>안티앨리어싱 사용</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="49"/>
        <source>Image Setup</source>
        <translation>이미지 설정</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="52"/>
        <source>Image width:</source>
        <translation>이미지 너비:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="53"/>
        <source>Image height:</source>
        <translation>이미지 높이:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="54"/>
        <source>Margins:</source>
        <translation>여백:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="61"/>
        <source>File:</source>
        <translation>파일:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="68"/>
        <source>Output file</source>
        <translation>출력 파일</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="75"/>
        <source>Export</source>
        <translation>내보내기</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="95"/>
        <source>Export to PNG</source>
        <translation>PNG로 내보내기</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="103"/>
        <source>Error</source>
        <translation>오류</translation>
    </message>
</context>
<context>
    <name>PolygonItem</name>
    <message>
        <location filename="../src/GUI/areaitem.cpp" line="18"/>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <location filename="../src/GUI/areaitem.cpp" line="20"/>
        <source>Description</source>
        <translation>설명</translation>
    </message>
</context>
<context>
    <name>PowerGraph</name>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="11"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="12"/>
        <location filename="../src/GUI/powergraph.h" line="16"/>
        <source>Power</source>
        <translation>파워</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>평균</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="30"/>
        <source>Max</source>
        <translation>최대</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="33"/>
        <source>Average</source>
        <translation>평균</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>최대</translation>
    </message>
</context>
<context>
    <name>PowerGraphItem</name>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="18"/>
        <source>Maximum</source>
        <translation>최대</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="19"/>
        <location filename="../src/GUI/powergraphitem.cpp" line="21"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="20"/>
        <source>Average</source>
        <translation>평균</translation>
    </message>
</context>
<context>
    <name>RouteItem</name>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="16"/>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="18"/>
        <source>Description</source>
        <translation>설명</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="20"/>
        <source>Comment</source>
        <translation>주석</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="21"/>
        <source>Distance</source>
        <translation>거리</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="32"/>
        <source>Links</source>
        <translation>링크</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="38"/>
        <source>File</source>
        <translation>파일</translation>
    </message>
</context>
<context>
    <name>ScaleItem</name>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="108"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="109"/>
        <location filename="../src/GUI/scaleitem.cpp" line="112"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="111"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="114"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="115"/>
        <source>m</source>
        <translation>m</translation>
    </message>
</context>
<context>
    <name>SpeedGraph</name>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="15"/>
        <location filename="../src/GUI/speedgraph.h" line="18"/>
        <source>Speed</source>
        <translation>속도</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="30"/>
        <source>min/km</source>
        <translation>min/km</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="31"/>
        <source>min/mi</source>
        <translation>min/mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="31"/>
        <source>min/nmi</source>
        <translation>min/nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="34"/>
        <source>Avg</source>
        <translation>평균</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="36"/>
        <source>Max</source>
        <translation>최대</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="39"/>
        <source>Average</source>
        <translation>평균</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="41"/>
        <source>Maximum</source>
        <translation>최대</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="44"/>
        <source>Pace</source>
        <translation>속도</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="146"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="149"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="152"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
</context>
<context>
    <name>SpeedGraphItem</name>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="25"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="26"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="26"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="29"/>
        <source>min/km</source>
        <translation>min/km</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="30"/>
        <source>min/mi</source>
        <translation>min/mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="30"/>
        <source>min/nmi</source>
        <translation>min/nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="33"/>
        <source>Maximum</source>
        <translation>최대</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="35"/>
        <source>Average</source>
        <translation>평균</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="37"/>
        <source>Pace</source>
        <translation>속도</translation>
    </message>
</context>
<context>
    <name>TemperatureGraph</name>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="12"/>
        <location filename="../src/GUI/temperaturegraph.h" line="16"/>
        <source>Temperature</source>
        <translation>온도</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>평균</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="30"/>
        <source>Min</source>
        <translation>최소</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="32"/>
        <source>Max</source>
        <translation>최대</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="35"/>
        <source>Average</source>
        <translation>평균</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="37"/>
        <source>Minimum</source>
        <translation>최소</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="39"/>
        <source>Maximum</source>
        <translation>최대</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="112"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="116"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>TemperatureGraphItem</name>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="23"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="23"/>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="26"/>
        <source>Average</source>
        <translation>평균</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="28"/>
        <source>Maximum</source>
        <translation>최대</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="30"/>
        <source>Minimum</source>
        <translation>최소</translation>
    </message>
</context>
<context>
    <name>TrackItem</name>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="15"/>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="17"/>
        <source>Description</source>
        <translation>설명</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="19"/>
        <source>Comment</source>
        <translation>주석</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="20"/>
        <source>Distance</source>
        <translation>거리</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="23"/>
        <source>Total time</source>
        <translation>총 시간</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="25"/>
        <source>Moving time</source>
        <translation>이동 시간</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="28"/>
        <source>Date</source>
        <translation>날짜</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="40"/>
        <source>Links</source>
        <translation>링크</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="46"/>
        <source>File</source>
        <translation>파일</translation>
    </message>
</context>
<context>
    <name>WaypointItem</name>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="26"/>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="27"/>
        <source>Coordinates</source>
        <translation>좌표</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="34"/>
        <source>Elevation</source>
        <translation>고도</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="38"/>
        <source>Date</source>
        <translation>날짜</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="43"/>
        <source>Description</source>
        <translation>설명</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="47"/>
        <source>Comment</source>
        <translation>주석</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="50"/>
        <source>Symbol</source>
        <translation>심볼</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="55"/>
        <source>Address</source>
        <translation>주소</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="58"/>
        <source>Phone</source>
        <translation>전화</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="68"/>
        <source>Links</source>
        <translation>링크</translation>
    </message>
</context>
</TS>
